@@ -25,7 +25,9 @@ __all__ = [
     'SUPPORTED_GIT_COMMANDS',
     'HTTP_200_OK',
     'HTTP_404_NOT_FOUND',
-    'PLUGIN_DEFAULT_CONFIG'
+    'PLUGIN_DEFAULT_CONFIG',
+    'ROOT_MOUNTPOUNT',
+    'JS_FILES',
 ]
 
 PLUGIN_NAME = 'code_editor'
@@ -51,7 +53,7 @@ SUPPORTED_GIT_COMMANDS = [
     'stage',
     'status',
     'tag',
-    'unstage'
+    'unstage',
 ]
 PLUGIN_DEFAULT_CONFIG = {
     'git_cmd': 'git',
@@ -59,5 +61,32 @@ PLUGIN_DEFAULT_CONFIG = {
     'git_author_name': None,
     'git_author_email': None,
     'git_init_repo': True,
-    'root_directory': None
+    'root_directory': None,
+    'line_length': 88,
+    'string_normalization': False,
 }
+ROOT_MOUNTPOUNT = 'root'
+JS_FILES = [
+    'codemirror.js',
+    'mode/python/python.js',
+    'addon/fold/foldcode.js',
+    'addon/fold/foldgutter.js',
+    'addon/fold/indent-fold.js',
+    'addon/fold/comment-fold.js',
+    'addon/mode/loadmode.js',
+    'addon/mode/simple.js',
+    'addon/mode/overlay.js',
+    'addon/dialog/dialog.js',
+    'addon/search/searchcursor.js',
+    'addon/search/search.js',
+    'addon/search/jump-to-line.js',
+    'mode/meta.js',
+    'bootstrap-dialog.js',
+    'vim.js',
+    'emacs.js',
+    'sublime.js',
+    'vue.js',
+    'themes.js',
+    'gitweb.js',
+    'vue_components.js',
+]
